# PyShuttle
Cross-chain atomic swaps between the networks of two cryptocurrencies.

## Version
* v0.1.0
    * The first proper release
    * ADDED: [Bytom](https://github.com/bytom/bytom) & [Bitcoin](https://github.com/bitcoin/bitcoin) cryptocurrencies.
* v0.0.1
    * Work in progress

## Meta

Meheret Tesfaye – [@meherett](https://github.com/meherett) – meherett@zoho.com

Distributed under the AGPL-3.0 license. See ``LICENSE`` for more information.

[https://github.com/meherett/pyshuttle](LICENSE)

## License
[AGPL-3.0](LICENSE)
